==> asyncnetfsm-0.1.1.tar.gz: asyncnetfsm-0.1.1/asyncnetfsm/dispatcher.py <==
"""
Factory function for creating netdev classes
"""
from asyncnetfsm.vendors import AristaEOS
from asyncnetfsm.vendors import ArubaAOS6, ArubaAOS8
from asyncnetfsm.vendors import CiscoASA, CiscoIOS, CiscoIOSXR, CiscoNXOS
from asyncnetfsm.vendors import FujitsuSwitch
from asyncnetfsm.vendors import HPComware, HPComwareLimited
from asyncnetfsm.vendors import JuniperJunOS
from asyncnetfsm.vendors import MikrotikRouterOS
from asyncnetfsm.vendors import Terminal
from asyncnetfsm.vendors import UbiquityEdgeSwitch
from asyncnetfsm.vendors import HW1000
from asyncnetfsm.vendors import FortinetFortigate

# @formatter:off
# The keys of this dictionary are the supported device_types
CLASS_MAPPER = {
    "arista_eos": AristaEOS,
    "aruba_aos_6": ArubaAOS6,
    "aruba_aos_8": ArubaAOS8,
    "cisco_asa": CiscoASA,
    "cisco_ios": CiscoIOS,
    "cisco_ios_xe": CiscoIOS,
    "cisco_ios_xr": CiscoIOSXR,
    "cisco_nxos": CiscoNXOS,
    "fujitsu_switch": FujitsuSwitch,
    "hp_comware": HPComware,
    "fortinet": FortinetFortigate,
    "hp_comware_limited": HPComwareLimited,
    "juniper_junos": JuniperJunOS,
    "mikrotik_routeros": MikrotikRouterOS,
    "ubiquity_edge": UbiquityEdgeSwitch,
    "terminal": Terminal,
    "hw1000": HW1000,
}

# @formatter:on

platforms = list(CLASS_MAPPER.keys())
platforms.sort()
platforms_str = u"\n".join(platforms)


def create(*args, **kwargs):
    """Factory function selects the proper class and creates object based on device_type"""
    if kwargs["device_type"] not in platforms:
        raise ValueError(
            "Unsupported device_type: "
            "currently supported platforms are: {0}".format(platforms_str)
        )
    connection_class = CLASS_MAPPER[kwargs["device_type"]]
    return connection_class(*args, **kwargs)

==> asyncnetfsm-0.1.3.tar.gz: asyncnetfsm-0.1.3/asyncnetfsm/dispatcher.py <==
"""
Factory function for creating netdev classes
"""
from asyncnetfsm.vendors import AristaEOS
from asyncnetfsm.vendors import ArubaAOS6, ArubaAOS8
from asyncnetfsm.vendors import CiscoASA, CiscoIOS, CiscoIOSXR, CiscoNXOS, CiscoFTD
from asyncnetfsm.vendors import FujitsuSwitch
from asyncnetfsm.vendors import HPComware, HPComwareLimited
from asyncnetfsm.vendors import JuniperJunOS
from asyncnetfsm.vendors import MikrotikRouterOS
from asyncnetfsm.vendors import Terminal
from asyncnetfsm.vendors import UbiquityEdgeSwitch
from asyncnetfsm.vendors import HW1000
from asyncnetfsm.vendors import FortinetFortigate

# @formatter:off
# The keys of this dictionary are the supported device_types
CLASS_MAPPER = {
    "arista_eos": AristaEOS,
    "aruba_aos_6": ArubaAOS6,
    "aruba_aos_8": ArubaAOS8,
    "cisco_asa": CiscoASA,
    "cisco_ftd": CiscoFTD,
    "cisco_ios": CiscoIOS,
    "cisco_ios_xe": CiscoIOS,
    "cisco_ios_xr": CiscoIOSXR,
    "cisco_nxos": CiscoNXOS,
    "fujitsu_switch": FujitsuSwitch,
    "hp_comware": HPComware,
    "fortinet": FortinetFortigate,
    "hp_comware_limited": HPComwareLimited,
    "juniper_junos": JuniperJunOS,
    "mikrotik_routeros": MikrotikRouterOS,
    "ubiquity_edge": UbiquityEdgeSwitch,
    "terminal": Terminal,
    "hw1000": HW1000,
}

# @formatter:on

platforms = list(CLASS_MAPPER.keys())
platforms.sort()
platforms_str = u"\n".join(platforms)


def create(*args, **kwargs):
    """Factory function selects the proper class and creates object based on device_type"""
    if kwargs["device_type"] not in platforms:
        raise ValueError(
            "Unsupported device_type: "
            "currently supported platforms are: {0}".format(platforms_str)
        )
    connection_class = CLASS_MAPPER[kwargs["device_type"]]
    return connection_class(*args, **kwargs)
